## dbt-adapters 1.17.0 - September 29, 2025

### Features

- Initial framework for UDF support ([#1268](https://github.com/dbt-labs/dbt-adapters/issues/1268))

### Fixes

- Fix duplicates when hard_deletes new_record is used with custom dbt_valid_to_current ([#1240](https://github.com/dbt-labs/dbt-adapters/issues/1240))
- Update function related global macros to use `default__` naming scheme ([#1356](https://github.com/dbt-labs/dbt-adapters/issues/1356))

### Contributors
- [@jeremyyeo](https://github.com/jeremyyeo) ([#1240](https://github.com/dbt-labs/dbt-adapters/issues/1240))
